/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */
package consts

const (
	ContextKeyStore        = "_context_key_storage"
	ContextKeyCluster      = "_context_key_cluster"
	ContextKeyClusterShard = "_context_key_cluster_shard"
	ContextKeyRaftNode     = "_context_key_raft_node"
)

const (
	HeaderIsRedirect           = "X-Is-Redirect"
	HeaderDontCheckClusterMode = "X-Dont-Check-Cluster-Mode"
)
